pub fn beta_cascade<F: Field>(
mles: &[&impl Mle<F>],
degree: usize,
round_index: usize,
beta_vals_vec: &[Vec<F>],
beta_updated_vals_vec: &[Vec<F>],
random_coefficients: &[F],
) -> SumcheckEvals<F>Expand description
this is how we compute the evaluations of a product of mle refs along with a beta table. rather than using the full expanded version of a beta table, we instead just use the beta values vectors (which are unbound beta values, and the bound beta values) there are (degree + 1) evaluations that are returned which are the evaluations of the univariate polynomial where the “round_index”-th bit is the independent variable.