pub(crate) fn apply_updated_beta_values_to_evals<F: Field>(
evals: Vec<F>,
folded_updated_vals: F,
) -> SumcheckEvals<F>Expand description
This is the final step of beta cascade, where we take all the “bound” beta values and scale all of the evaluations by the product of all of these values.