pub fn beta_cascade_no_independent_variable<F: Field>(
evaluated_bookkeeping_table: Vec<F>,
beta_vals: &[F],
beta_updated_vals: &[F],
degree: usize,
) -> SumcheckEvals<F>Expand description
Similar to beta_cascade, but does not compute any evaluations and simply multiplies the appropriate beta values by the evaluated bookkeeping table.